// Copyright © 2023 ESWIN. All rights reserved.
//
// Beijing ESWIN Computing Technology Co., Ltd and its affiliated companies ("ESWIN") retain
// all intellectual property and proprietary rights in and to this software. Except as expressly
// authorized by ESWIN, no part of the software may be released, copied, distributed, reproduced,
// modified, adapted, translated, or created derivative work of, in whole or in part.

#ifndef ES_NPU_ERROR_H
#define ES_NPU_ERROR_H
#include "es_errno.h"
#include "es_common.h"

#define ES_NPU_ERROR_BASE ES_DEF_ERR(ES_ID_NPU, EN_ERR_LEVEL_ERROR, 0)
#define ES_NPU_ERROR_NUM(X) (ES_NPU_ERROR_BASE + X)

#define ES_NPU_ERROR_BAD_PARAM ES_NPU_ERROR_NUM(EN_ERR_ILLEGAL_PARAM)
#define ES_NPU_ERROR_NULL_PTR ES_NPU_ERROR_NUM(EN_ERR_NULL_PTR)
#define ES_NPU_ERROR_NO_MEMORY ES_NPU_ERROR_NUM(EN_ERR_NOMEM)
#define ES_NPU_ERROR_INVALID_ADDR ES_NPU_ERROR_NUM(EN_ERR_BADADDR)
#define ES_NPU_ERROR_BUSY ES_NPU_ERROR_NUM(EN_ERR_BUSY)
#define ES_NPU_ERROR_NOT_INIT ES_NPU_ERROR_NUM(64)
#define ES_NPU_ERROR_TIME_OUT ES_NPU_ERROR_NUM(65)
#define ES_NPU_ERROR_INVALID_STATE ES_NPU_ERROR_NUM(66)
#define ES_NPU_ERROR_INVALID_SIZE ES_NPU_ERROR_NUM(67)
#define ES_NPU_ERROR_BAD_VALUE ES_NPU_ERROR_NUM(68)
#define ES_NPU_ERROR_DEV_NOT_FOUND ES_NPU_ERROR_NUM(69)
#define ES_NPU_ERROR_DEV_MULTI_SET ES_NPU_ERROR_NUM(70)
#define ES_NPU_ERROR_DEV_OPEN_FAILED ES_NPU_ERROR_NUM(71)
#define ES_NPU_ERROR_MODEL_NOT_PRESENT ES_NPU_ERROR_NUM(72)
#define ES_NPU_ERROR_MODEL_NOT_FOUND ES_NPU_ERROR_NUM(73)
#define ES_NPU_ERROR_CONTEXT_NOT_FOUND ES_NPU_ERROR_NUM(74)
#define ES_NPU_ERROR_CONTEXT_INVALID ES_NPU_ERROR_NUM(75)
#define ES_NPU_ERROR_STREAM_NOT_FOUND ES_NPU_ERROR_NUM(76)
#define ES_NPU_ERROR_STREAM_INVALID ES_NPU_ERROR_NUM(77)
#define ES_NPU_ERROR_TASK_NOT_FOUND ES_NPU_ERROR_NUM(78)
#define ES_NPU_ERROR_FILE_WRITE_FAIL ES_NPU_ERROR_NUM(79)
#define ES_NPU_ERROR_FILE_READ_FAIL ES_NPU_ERROR_NUM(80)
#define ES_NPU_ERROR_FILE_OPREATION_FAIL ES_NPU_ERROR_NUM(81)
#define ES_NPU_ERROR_END_OF_FILE ES_NPU_ERROR_NUM(82)
#define ES_NPU_ERROR_DIR_OPREATION_FAIL ES_NPU_ERROR_NUM(83)
#define ES_NPU_ERROR_END_OF_DIR_LIST ES_NPU_ERROR_NUM(84)
#define ES_NPU_ERROR_IOCTL_FAIL ES_NPU_ERROR_NUM(85)
#define ES_NPU_ERROR_CREAT_EVENTFD_FAIL ES_NPU_ERROR_NUM(86)
#define ES_NPU_ERROR_LOAD_OP_FAILED ES_NPU_ERROR_NUM(88)
#define ES_NPU_ERROR_SUBMIT_TASK_FAILED ES_NPU_ERROR_NUM(89)
#define ES_NPU_ERROR_LOAD_SRAM_FAIL ES_NPU_ERROR_NUM(90)
#define ES_NPU_ERROR_BAD_SRAM_SIZE ES_NPU_ERROR_NUM(91)
#define ES_NPU_ERROR_DSP_QUERY_FAILED ES_NPU_ERROR_NUM(92)

#define CHECK_PARAM_IS_NULL(X)                                                             \
    if (X == NULL) {                                                                       \
        fprintf(stderr, "param is NULL at %s:%s:%d \n", __FILE__, __FUNCTION__, __LINE__); \
        return ES_NPU_ERROR_NULL_PTR;                                                      \
    }

#endif
